==> elgg-2.3.5.zip: elgg-2.3.5/mod/file/languages/fr.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'file' => "Fichiers",
	'file:user' => "Fichiers de %s",
	'file:friends' => "Fichiers des contacts",
	'file:all' => "Tous les fichiers du site",
	'file:edit' => "Modifier le fichier",
	'file:more' => "Plus de fichiers",
	'file:list' => "vue liste",
	'file:group' => "Fichiers du groupe",
	'file:gallery' => "vue galerie",
	'file:gallery_list' => "Vue \"liste\" ou \"galerie\"",
	'file:num_files' => "Nombre de fichiers à afficher",
	'file:user:gallery'=>'Voir la galerie %s',
	'file:upload' => "Envoyer un fichier",
	'file:replace' => 'Remplacer le contenu du fichier (ne rien sélectionner pour ne pas changer)',
	'file:list:title' => "de %s %s %s",
	'file:title:friends' => "des contacts",

	'file:add' => 'Envoyer un fichier',

	'file:file' => "Fichier",

	'file:list:list' => 'Basculer vers la vue en liste',
	'file:list:gallery' => 'Basculer vers la vue en galerie',

	'file:types' => "Type de fichiers téléchargés",

	'file:type:' => 'Fichiers',
	'file:type:all' => "Tous les fichiers",
	'file:type:video' => "Vidéos",
	'file:type:document' => "Documents",
	'file:type:audio' => "Audio",
	'file:type:image' => "Images",
	'file:type:general' => "Autres types de fichiers",

	'file:user:type:video' => "Vidéos de %s",
	'file:user:type:document' => "Documents de %s",
	'file:user:type:audio' => "Enregistrements audio de %s",
	'file:user:type:image' => "Images de %s",
	'file:user:type:general' => "Autres types de fichiers de %s",

	'file:friends:type:video' => "Vidéos des contacts",
	'file:friends:type:document' => "Documents des contacts",
	'file:friends:type:audio' => "Enregistrements audio des contacts",
	'file:friends:type:image' => "Images des contacts",
	'file:friends:type:general' => "Autres types de fichiers des contacts",

	'file:widget' => "Widget Fichiers",
	'file:widget:description' => "Affiche une liste de vos derniers fichiers",

	'groups:enablefiles' => 'Activer les fichiers de groupes',

	'file:delete:confirm' => "Confirmez-vous vouloir supprimer ce fichier ?",

	'file:upload_limit' => 'La taille de fichier maximale autorisée est de %s',

	'file:tagcloud' => "Nuage de tags",

	'file:display:number' => "Nombre de fichiers à afficher",

	'river:create:object:file' => '%s a chargé le fichier %s',
	'river:comment:object:file' => '%s a commenté le fichier %s',

	'item:object:file' => 'Fichiers',

	'file:notify:summary' => 'Nouveau fichier intitulé %s',
	'file:notify:subject' => 'Nouveau fichier: %s',
	'file:notify:body' =>
'%s à publié un nouveau fichier: %s

%s

Accéder à ce fichier et le commenter:
%s
',

	/**
	 * Status messages
	 */

	'file:saved' => "Votre fichier a bien été enregistré.",
	'file:deleted' => "Votre fichier a bien été supprimé.",

	/**
	 * Error messages
	 */

	'file:none' => "Aucun fichier pour le moment.",
	'file:uploadfailed' => "Désolé, votre fichier n'a pas pu être enregistré.",
	'file:downloadfailed' => "Désolé, ce fichier n'est pas disponible en ce moment.",
	'file:deletefailed' => "Votre fichier n'a pas pu être supprimé.",
	'file:noaccess' => "Vous n'avez pas la permission de modifier ce fichier",
	'file:cannotload' => "Une erreur s'est produite lors de l'envoi du fichier",
	'file:nofile' => "Vous devez sélectionner un fichier",
);

==> elgg-3.0.5.zip: elgg-3.0.5/mod/file/languages/fr.php <==
<?php
return array(

	'item:object:file' => 'Fichiers',
	'collection:object:file' => 'Fichiers',
	'collection:object:file:all' => "Tous les fichiers du site",
	'collection:object:file:owner' => "Fichiers de %s",
	'collection:object:file:friends' => "Fichiers des contacts",
	'collection:object:file:group' => "Fichiers du groupe",
	'add:object:file' => "Envoyer un fichier",
	'edit:object:file' => "Modifier le fichier",

	'file:more' => "Plus de fichiers",
	'file:list' => "vue liste",

	'file:num_files' => "Nombre de fichiers à afficher",
	'file:replace' => 'Remplacer le contenu du fichier (ne rien sélectionner pour ne pas changer)',
	'file:list:title' => "de %s %s %s",
	'file:title:friends' => "des contacts",

	'file:file' => "Fichier",

	'file:list:list' => 'Basculer vers la vue en liste',
	'file:list:gallery' => 'Basculer vers la vue en galerie',

	'file:types' => "Type de fichiers téléchargés",

	'file:type:' => 'Fichiers',
	'file:type:all' => "Tous les fichiers",
	'file:type:video' => "Vidéos",
	'file:type:document' => "Documents",
	'file:type:audio' => "Audio",
	'file:type:image' => "Images",
	'file:type:general' => "Autres types de fichiers",

	'file:user:type:video' => "Vidéos de %s",
	'file:user:type:document' => "Documents de %s",
	'file:user:type:audio' => "Enregistrements audio de %s",
	'file:user:type:image' => "Images de %s",
	'file:user:type:general' => "Autres types de fichiers de %s",

	'file:friends:type:video' => "Vidéos des contacts",
	'file:friends:type:document' => "Documents des contacts",
	'file:friends:type:audio' => "Enregistrements audio des contacts",
	'file:friends:type:image' => "Images des contacts",
	'file:friends:type:general' => "Autres types de fichiers des contacts",

	'widgets:filerepo:name' => "Widget Fichiers",
	'widgets:filerepo:description' => "Affiche une liste de vos derniers fichiers",

	'groups:tool:file' => 'Activer les fichiers du groupe',

	'river:object:file:create' => '%s a chargé le fichier %s',
	'river:object:file:comment' => '%s a commenté le fichier %s',

	'file:notify:summary' => 'Nouveau fichier intitulé %s',
	'file:notify:subject' => 'Nouveau fichier: %s',
	'file:notify:body' => '%s a chargé un nouveau fichier : %s

%s

Afficher et commenter le fichier :
%s',

	/**
	 * Status messages
	 */

	'file:saved' => "Le fichier a bien été enregistré.",
	'entity:delete:object:file:success' => "Le fichier a bien été supprimé.",

	/**
	 * Error messages
	 */

	'file:none' => "Aucun fichier pour le moment.",
	'file:uploadfailed' => "Désolé, votre fichier n'a pas pu être enregistré.",
	'file:noaccess' => "Vous n'avez pas la permission de modifier ce fichier",
	'file:cannotload' => "Une erreur s'est produite lors de l'envoi du fichier",
);
